const app = getApp()
import request from '../../utils/request'
import { scrollToID } from '../../utils/util'
Page({

  /**
   * 页面的初始数据
   */
  data: {
    chatList: [],
    saysContentLength: 50,
    message: "",
    waitingMessage: "",
    isResponing: false,
    chatOver: false,
    messageFlag: true,
    istouching: false,
    isHolding: false,
    scrollTop: 0,
    timer: null,
    clearTimer: null
  },

  /**
   * 生命周期函数--监听页面加载
   */
  onLoad() {
    this.socketLink()
    this.chatLimit()
  },

  chatLimit() {
    request.get({
      url: '/api/chat/limit',
    }).then(res => {
      console.log(res, 'chatLimit');
      this.setData({
        saysContentLength: res.data.saysContentLength * 1
      })
    }).catch(err => {
      console.log(err, 'err');
    })
  },

  input(e) {
    const msg = e.detail.value
    const limit = this.data.saysContentLength
    if (msg.length > limit) {
      wx.showToast({
        title: `单条最长可输入字数为${limit}字！`,
        icon: 'none'
      })
    }
    this.setData({
      message: msg
    })
  },

  // 向socket连接端发送数据
  send() {
    if (!this.data.message) return

    // 当socket连接被关闭时，重新连接socket
    if (this.data.reLoadSocket) {
      this.socketLink()
      this.setData({
        waitingMessage: this.data.message
      })
    }

    const data = {
      message: this.data.message,
      id: 1 // 带id为用户发送的讯息，不带则为服务器返回的讯息
    }

    const arr = this.data.chatList
    arr.push(data)

    // 非重载状态下向服务器发送讯息
    if (!this.data.reLoadSocket) {
      this.socketSend(this.data.message)
    }

    this.setData({
      chatList: arr,
      message: '',
      messageFlag: true
    })
    console.log(this.data.chatList, 'chatList');
  },

  // 打招呼信息
  sayHello(message) {
    const messageArr = message.split('，')
    const len = messageArr.length
    let msg = ''
    let i = 0;
    let timer = setInterval(() => {
      const arr = this.data.chatList
      arr.splice(arr.length - 1, '1')
      msg += i + 1 == len ? messageArr[i] : messageArr[i] + '，';
      const data = {
        message: msg
      }
      arr.push(data)
      this.setData({
        chatList: arr,
      })
      if (i + 1 == len) {
        clearInterval(timer);
      } else {
        i++;
      }
    }, 150);
  },

  // 插入的信息，高频触发，每一次返回插入一条信息
  messageIn(message) {
    // 第一次触发
    const tempArr = this.data.chatList
    if (this.data.messageFlag) {
      const data = { message }
      tempArr.push(data)
      this.setData({
        chatList: tempArr,
        messageFlag: false
      })
    } else {
      tempArr[tempArr.length - 1].message += message
      this.setData({
        chatList: tempArr
      })
    }
  },

  // 进行socket连接
  socketLink() {
    const that = this
    wx.connectSocket({
      url: 'wss://gptsockettest.malls.iformall.com:8010',
      header: {
        'content-type': 'application/json'
      },
      success: function (res) {
        console.log(res)
        if (!that.data.reLoadSocket) {
          that.sayHello('Hello，我是小闲聊，你可以和我聊天，😘😘😘')
        }

        if (that.data.waitingMessage) {
          that.socketSend(that.data.waitingMessage)
          that.setData({
            reLoadSocket: false
          })
        }

        wx.onSocketClose(() => {
          console.log('Socket连接已关闭');
          that.scrollToBottom('scrollSingel')
          that.setData({
            reLoadSocket: true
          })
        })
      },
      fail: function (err) {
        console.log(err)
      },
      complete: function (info) {
        console.log(info)
      }
    })
  },

  socketSend(data) {
    const that = this
    const msgArr = []
    wx.sendSocketMessage({
      data: data,
      success: function (res) {
        console.log(res)
        wx.onSocketMessage(data => {
          const msgBack = data.data
          console.log(msgBack);
          if (msgBack == '___talk_end___') {
            that.setData({
              isResponing: false
            })
            // setTimeout(() => {
            //   console.log('10s');
            // }, 10000);
          } else {
            that.messageIn(msgBack)
            that.scrollToBottom('scrollSingel')
            that.setData({
              isResponing: true
            })
          }
        })
      },
      fail: function (err) {
        console.log(err)
      },
      complete: function (info) {
        console.log(info)
      }
    })
  },

  /* 滚动到选定dom的底部 */
  scrollToBottom(id) {
    const that = this
    wx.createSelectorQuery().select('#' + id).boundingClientRect(function (rect) {
      wx.pageScrollTo({
        scrollTop: rect.height,
        duration: 100 // 滑动速度
      })
      that.setData({
        scrollTop: rect.height - that.data.scrollTop
      });
    }).exec();
  },

  // 点击开始，在触发messageTouchEnd之前即为长按
  messageTouchStart(e) {
    const timer = this.data.timer
    const clearTimer = this.data.clearTimer
    clearTimeout(timer)
    clearTimeout(clearTimer)
    this.setData({
      timer: null,
      clearTimer: null,
    })

    this.setData({
      istouching: true,
      istouchingIndex: e.currentTarget.dataset.index,
      timer: setTimeout(() => {
        this.setData({
          isHolding: true
        })
      }, 200)
    })
  },

  // 点击结束
  messageTouchEnd(e) {
    this.setData({
      istouching: false,
      istouchingIndex: e.currentTarget.dataset.index,
      clearTimer: setTimeout(() => {
        this.setData({
          isHolding: false
        })
      }, 4000)
    })
    const timer = this.data.timer
    clearTimeout(timer)
  },

  // 复制信息
  copyMessage(e) {
    if (!this.data.isHolding) return
    const message = e.currentTarget.dataset.message
    this.setData({
      isHolding: false
    })
    const timer = this.data.timer
    clearTimeout(timer)

    this.setClipboardData(message)
  },

  // 监听聊天区域点击事件
  contentWatch(e) {
    console.log(e);
  },

  /* 复制内容到剪贴板*/
  setClipboardData(data) {
    wx.setClipboardData({
      data,
      success(res) {
        // console.log(res)
      }
    })
  },


  /**
   * 生命周期函数--监听页面初次渲染完成
   */
  onReady() {

  },

  /**
   * 生命周期函数--监听页面显示
   */
  onShow() {

  },

  /**
   * 生命周期函数--监听页面隐藏
   */
  onHide() {

  },

  /**
   * 生命周期函数--监听页面卸载
   */
  onUnload() {

  },

  /**
   * 页面相关事件处理函数--监听用户下拉动作
   */
  onPullDownRefresh() {

  },

  /**
   * 页面上拉触底事件的处理函数
   */
  onReachBottom() {

  },

  /**
   * 用户点击右上角分享
   */
  onShareAppMessage() {

  }
})