const app = getApp()
import request from '../../utils/request'
import { timestampToTime } from '../../utils/util'

Page({
  data: {
    userInfo: {},
    hasUserInfo: false,
    canIUse: wx.canIUse('button.open-type.getUserInfo'),
    canIUseGetUserProfile: false,
    canIUseOpenData: wx.canIUse('open-data.type.userAvatarUrl') && wx.canIUse('open-data.type.userNickName'),
    isPhone: false
  },
  // 事件处理函数
  bindViewTap() {
    wx.navigateTo({
      url: '../logs/logs',
    })
  },
  onLoad(option) {
    if (option.checkUserInfo) {
      this.checkUserInfo()
    }
    const that = this
    app.userInfoCallback = res => {
      console.log(res, 'userInfoCallback')
      that.setData({
        userInfo: res.data,
        isPhone: that.data.userInfo.phone ? true : false
      })
    }

  },
  getUserProfile() {
    // 推荐使用wx.getUserProfile获取用户信息，开发者每次通过该接口获取用户个人信息均需用户确认，开发者妥善保管用户快速填写的头像昵称，避免重复弹窗
    wx.getUserProfile({
      desc: '展示用户信息', // 声明获取用户个人信息后的用途，后续会展示在弹窗中，请谨慎填写
      success: (res) => {
        console.log(res, 'getUserProfile')
      }
    })
  },

  // 跳转至购买历史页面
  checkPayHistory() {
    wx.navigateTo({
      url: '/pages/payHistory/payHistory',
    })
  },

  // 获取手机号授权
  getUserPhone(e) {
    const sessionKey = wx.getStorageSync('sessionKey')
    this.doGetUserPhone(e.detail.encryptedData, e.detail.iv, sessionKey, request.appId)
  },

  /** 获取手机号授权 */
  doGetUserPhone(encryptedData, iv, sessionKey, appId) {
    request.post({
      url: '/api/user/getUserPhone',
      data: {
        encryptedData,
        iv,
        sessionKey,
        appId
      }
    }).then(res => {
      console.log(res, 'getUserPhone');
      wx.showToast({
        title: '申请成功！',
        icon: 'success'
      })
      this.checkUserInfo()
    }).catch(err => {
      console.log(err, 'err');
    })
  },

  // 购买会员
  goToBuy() {
    const userInfo = JSON.stringify(this.data.userInfo)
    wx.navigateTo({
      url: `/pages/payOrder/payOrder?userInfo=${userInfo}`,
    })
  },

  goToChat() {
    wx.navigateTo({
      url: '/pages/chat/chat',
    })
  },

  /**
  * @description 检查用户信息
  * @returns userInfo
  */
  checkUserInfo() {
    request.get({
      url: '/api/user/userinfo'
    }).then(res => {
      console.log(res, 'userinfo');
      res.data.createDate = res.data.createDate ? timestampToTime(res.data.createDate, 'YYYY-MM-DD hh:mm:ss') : ''
      res.data.updateDate = res.data.updateDate ? timestampToTime(res.data.updateDate, 'YYYY-MM-DD hh:mm:ss') : ''
      res.data.validStartTime = res.data.validStartTime ? timestampToTime(res.data.validStartTime, 'YYYY-MM-DD hh:mm:ss') : ''
      res.data.validEndTime = res.data.validEndTime ? timestampToTime(res.data.validEndTime, 'YYYY-MM-DD hh:mm:ss') : ''
      this.setData({
        userInfo: res.data,
        isPhone: this.data.userInfo.phone ? true : false
      })
    }).catch(err => {
      console.log(err, 'err');
    })
  },
  onShareAppMessage() {
    const promise = new Promise(resolve => {
      setTimeout(() => {
        resolve({
          title: '小闲聊'
        })
      }, 500)
    })
    return {
      title: '小闲聊',
      path: '/page/index/index',
      promise
    }
  },
  onShareTimeline() {
    const promise = new Promise(resolve => {
      setTimeout(() => {
        resolve({
          title: '小闲聊'
        })
      }, 500)
    })
    return {
      title: '小闲聊',
      path: '/page/index/index',
      promise
    }
  }
})
